<?php
/**
 * This file fixes some issues generated by "Facebook Instant Articles & Google AMP Pages by PageFrog".
 *
 * We explained the issue in our blog: https://neliosoftware.com/blog/when-wordpress-freedom-kills-your-business/
 * And we asked for help here: https://wordpress.org/support/topic/your-plugin-generates-compatibility-issues/
 *
 * @package    Nelio_Content
 * @subpackage Nelio_Content/includes/compat
 * @author     David Aguilera <david.aguilera@neliosoftware.com>
 * @since      1.0.5
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}//end if

/**
 * This function adds a few hooks that modify pagefrog's default behavior,
 * fixing some of the issues it generates (which result in our plugin
 * breaking).
 *
 * @since 1.0.5
 */
function nc_compat_pagefrog_fix_issues_with_post_page() {

	if ( ! is_plugin_active( 'pagefrog/pagefrog.php' ) ) {
		return;
	}//end if

	$settings = Nelio_Content_Settings::instance();
	$calendar_post_types = $settings->get( 'calendar_post_types' );
	$screen = get_current_screen();
	if ( ! in_array( $screen->id, $calendar_post_types ) ) {
		return;
	}//end if

	add_action( 'admin_head', 'nc_compat_pagefrog_fix_global_css', 999 );

}//end nc_compat_pagefrog_fix_issues_with_post_page()
add_action( 'current_screen', 'nc_compat_pagefrog_fix_issues_with_post_page' );

/**
 * This function reverts the global CSS settings and applies them to only
 * pagefrog's meta box.
 *
 * @since 1.0.5
 */
function nc_compat_pagefrog_fix_global_css() { ?>

	<style type="text/css">

		:before, :after, * {
			-webkit-box-sizing: initial;
		  -moz-box-sizing: initial;
		  box-sizing: initial;
		}

		#pagefrog-preview-meta-box :before,
		#pagefrog-preview-meta-box :after,
		#pagefrog-preview-meta-box * {
			-webkit-box-sizing: border-box;
		  -moz-box-sizing: border-box;
		  box-sizing: border-box;
		}

	</style>

<?php
}//end nc_compat_pagefrog_fix_global_css()
